#!/usr/bin/perl
#
#   Bluestem - University of Illinois WWW Identification Service
#
#   test1.cgi - Bluestem API Test 1 CGI
#
#   Copyright 1996-1999 - Board of Trustees of the University of Illinois
#
#   Johnathan Kupferer <jtk@uic.edu>
#   ACCC
#   University of Illinois at Chicago
#
#---Revisions-----------------------------------------------

use strict;
use warnings;

use lib "/var/www/bluestem-client/lib";
use Bluestem;
require("ctime.pl");

my(
  $pid, $IDleMax, $Client, $ClientIP, $ClientCookie, $CacheID,
  $script_name, $ThisHost, $LogoutURL, $ID, $IdleTime, $SessionTime, $FullID,
  $IdleMax, $ClientCookieName, $User, $Domain, $Auth, $todc, $LoginTime,
  $ApplServerCache, $Version, $k, $v, @EnvVars
  );

#-----------------------------------------------------------
#   Main Program
#-----------------------------------------------------------

$IdleMax = 1 * 60 * 60;

#---CGI Info------------------------------------------------
$Client = $ENV{'REMOTE_HOST'};
$ClientIP = $ENV{'REMOTE_ADDR'};
$Client = $ClientIP unless $Client;
$ClientCookie = &Bluestem::cookie_read();
#   suppress display of ClientRandom secret
if( $ClientCookie ) {
    $ClientCookie =~ s/~[0-9a-f]+$/~****************/;
    ($CacheID) = $ClientCookie =~ m/^(\d+-\d+)~/;
}
$ClientCookieName = "Bluestem_$Bluestem::R_ServerNamePortCookie";

$script_name = $Bluestem::R_ScriptName;
$script_name =~ s|/[^/]+$|/logout|;
$script_name .= (($Bluestem::C_NT) ? '.pl' : '.cgi');
$ThisHost = $Bluestem::R_ServerNamePort;
$LogoutURL = "https://$ThisHost$script_name";


#---Valid API Calls-----------------------------------------
($ID, $IdleTime, $SessionTime) = &bluestem_id;
&bluestem_login('','') unless $ID;
&bluestem_login('', "$Client idle more than $IdleMax seconds.")
    if  $IdleTime > $IdleMax;

$FullID = &bluestem_id_full($ID);
($User,$Domain,$Auth) = &bluestem_id_parse($ID);

$IdleTime = &hhmmss($IdleTime);
$SessionTime = &hhmmss($SessionTime);
($todc, $pid) = split(/-/, $CacheID);
$LoginTime = &ctime($todc);

#---Peeking under the hood----------------------------------
open(Cache, "$Bluestem::C_CacheDir/$CacheID");
$ApplServerCache = <Cache>;
close(Cache);
#   suppress display of ClientRandom secret
$ApplServerCache =~ s/,[0-9a-f]{16}\b/,****************/;

$Version = $Bluestem::C_Version;

#---List Environement Variables-----------------------------
for $k(sort(keys(%ENV))) {
   $v = $ENV{$k};
   $v =~ s/(~|%7E)[0-9a-f]{16}/$1****************/g if $k eq 'HTTP_COOKIE';
   push(@EnvVars,"<tr><td><code>$k</code></td><td><code>$v</code></td></tr>\n");
   }

print "Content-type: text/html\n\n";
print <<"-30-";
   <html>
   <head>
   <title>Bluestem API Test 1 - $ThisHost</title>
   </head>
   <body>
   <center>
   <a href=http://www.uic.edu/>
   <img src="$Bluestem::C_ImgPath/UIbar.gif" border="none" width=468 height=20></a><br>
   <b><font size=+1>Bluestem API Test 1 - $ThisHost</font></b><br>
   <img src="$Bluestem::C_ImgPath/UIthinbar.gif" width=468 height=6><br>
   <a href=$LogoutURL><b>Logout from $ThisHost</b></a>
   <p>

   <table border>
   <tr><th>Bluestem Item</th>        <th>Value</th></tr>
   <tr><td>Version</td>		     <td align=center><b>$Version</b></td></tr>
   <tr><td>ID</td>                   <td align=center><b>$ID</b></td></tr>
   <tr><td>ID (full)</td>            <td align=center><b>$FullID</b></td></tr>
   <tr><td>User</td>                 <td align=center><b>$User</b></td></tr>
   <tr><td>Domain</td>               <td align=center><b>$Domain</b></td></tr>
   <tr><td>Authentication Method</td><td align=center><b>$Auth</b></td></tr>
   <tr><td>Application Server</td>   <td align=center><b>$ThisHost</b></td></tr>
   <tr><td>Client</td>               
       <td align=center><b>$Client($ClientIP)</b></td></tr>
   <tr><td>Cache-ID</td>             
       <td align=center><b>$CacheID</b></td></tr>
   <tr><td>Client Cookie Name</td>        
       <td align=center><b><font size=-1>$ClientCookieName</font></b></td></tr>
   <tr><td>Client Cookie Value</td>        
       <td align=center><b><font size=-1>$ClientCookie</font></b></td></tr>
   <tr><td>Application Server Cache</td>   
       <td align=center><b><font size=-1>$ApplServerCache</font></b></td></tr>
   <tr><td>Login Time</td>           
       <td align=center><b>$LoginTime</b></td></tr>
   <tr><td>Session Time (hh:mm:ss)</td>
       <td align=center><b>$SessionTime</b></td></tr>
   <tr><td>Idle Time (hh:mm:ss)</td>
       <td align=center><b>$IdleTime</b></td></tr>
   </table>
   <p>
   <table border>
   <tr><th>Environment Variable</th><th>Value</th></tr>
   @EnvVars
   </table>
   </center>
   <hr>
   <address>UIC WWW Identification Service -
   <a href=mailto:www\@uic.edu>www\@uic.edu</a>
   </address>
   </body>
   </html>
-30-






exit;


sub hhmmss {
   my($secs) = @_;
   my($hr, $mi, $sc, $hhmmss);
   
   $sc = int($secs%60);
   $mi = int(int($secs/60)%60);
   $hr = int($secs/3600);
   
   $hhmmss = sprintf("%d:%02d:%02d", $hr, $mi, $sc);
   $hhmmss =~ s/^[0:]+//;
   $hhmmss = '0' unless $hhmmss;
   $hhmmss;
   }

  
